
import { StrictMode } from "react";
import { createRoot } from "react-dom/client";
import App from "./App.tsx";
import "./index.css";
import { performanceMonitor, registerServiceWorker } from "./utils/performanceMonitoring";

const rootElement = document.getElementById("root");
if (!rootElement) throw new Error('Failed to find the root element');

// Track app initialization performance
const appStartTime = performance.now();

// Initialize module error tracking
performanceMonitor.trackModuleErrors();

// Register service worker for offline caching
registerServiceWorker();

// Create and render the app
const root = createRoot(rootElement);
root.render(
  <StrictMode>
    <App />
  </StrictMode>,
);

// Enhanced performance tracking with cache monitoring
window.addEventListener('load', () => {
  performanceMonitor.trackBundleLoad('main-app', appStartTime);
  
  // Enhanced performance metrics logging in development
  if (process.env.NODE_ENV === 'development') {
    setTimeout(() => {
      const metrics = performanceMonitor.getPerformanceMetrics();
      console.table(metrics);
      
      // Generate comprehensive performance report
      const report = performanceMonitor.generatePerformanceReport();
      console.log(report);
      
      // Check for module loading issues with cache context
      const moduleResources = performance.getEntriesByType('resource').filter(
        (resource: PerformanceResourceTiming) => 
          resource.name.includes('.js') || 
          resource.name.includes('.tsx') || 
          resource.name.includes('.ts')
      );
      
      if (moduleResources.length > 0) {
        const cachedModules = moduleResources.filter(
          (resource: PerformanceResourceTiming) => 
            resource.transferSize === 0 && resource.decodedBodySize > 0
        );
        
        console.log(`📊 JavaScript modules: ${moduleResources.length} total, ${cachedModules.length} cached (${((cachedModules.length / moduleResources.length) * 100).toFixed(1)}% cache hit rate)`);
      }
    }, 1000);
  }
});

// Monitor cache performance in production
if (process.env.NODE_ENV === 'production') {
  // Report cache metrics every 5 minutes
  setInterval(() => {
    const metrics = performanceMonitor.getPerformanceMetrics();
    if (metrics.cacheHitRate > 0) {
      console.log(`📊 Cache performance: ${metrics.cacheHitRate.toFixed(1)}% hit rate, ${(metrics.bandwidthSaved / 1024).toFixed(1)}KB saved`);
    }
  }, 5 * 60 * 1000);
}
